@@ -14,6 +14,14 @@ var addOperatorScenarios = []expressionScenario{
 			"D0, P[1 a], (!!int)::3\n",
 		},
 	},
+	{
+		skipDoc:    true,
+		document:   `a: key`,
+		expression: `. += {"key": "b"}`,
+		expected: []string{
+			"D0, P[], (!!map)::a: key\nkey: b\n",
+		},
+	},
 	{
 		skipDoc:    true,
 		document:   `[[c], [b]]`,
